==> qmmp_1.1.4.orig.tar.bz2: qmmp-1.1.4/src/plugins/Input/wavpack/translations/wavpack_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="44"/>
        <source>WavPack Plugin</source>
        <translation>WavPack Eklentisi</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="46"/>
        <source>WavPack Files</source>
        <translation>WavPack Dosyaları</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="160"/>
        <source>About WavPack Audio Plugin</source>
        <translation>WavPack Ses Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="161"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Qmmp WavPack Ses Eklentisi</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="162"/>
        <source>WavPack library version:</source>
        <translation>WavPack kitaplık sürümü:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="164"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>WavPackMetaDataModel</name>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="70"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>Sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation type="unfinished">Hz</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>kbps</source>
        <translation type="unfinished">kbps</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="75"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="75"/>
        <source>KB</source>
        <translation type="unfinished">KB</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="76"/>
        <source>Ratio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="77"/>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Input/wavpack/translations/wavpack_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="38"/>
        <source>WavPack Plugin</source>
        <translation>WavPack Eklentisi</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="40"/>
        <source>WavPack Files</source>
        <translation>WavPack Dosyaları</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="153"/>
        <source>About WavPack Audio Plugin</source>
        <translation>WavPack Ses Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="154"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Qmmp WavPack Ses Eklentisi</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="155"/>
        <source>WavPack library version:</source>
        <translation>WavPack kitaplık sürümü:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="157"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>WavPackMetaDataModel</name>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="70"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>Sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation type="unfinished">Hz</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>kbps</source>
        <translation type="unfinished">kbps</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="75"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="75"/>
        <source>KB</source>
        <translation type="unfinished">KB</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="76"/>
        <source>Ratio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="77"/>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
